==> texmacs_1.0.7.7.orig.tar.gz: TeXmacs-1.0.7.7-src/src/Plugins/Qt/QTMGuiHelper.hpp <==

/******************************************************************************
* MODULE     : QTMGuiHelper.hpp
* DESCRIPTION: QT Gui helper class
* COPYRIGHT  : (C) 2008 Massimiliano Gubinelli
*******************************************************************************
* This software falls under the GNU general public license version 3 or later.
* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
******************************************************************************/

#ifndef QTMGUIHELPER_HPP
#define QTMGUIHELPER_HPP

#include "qt_gui.hpp"
#include "Scheme/object.hpp"
#include <QObject>
#include <QAction>
#include <QTranslator>

class QTMGuiHelper : public QObject {
  Q_OBJECT
  qt_gui_rep* gui;

public:
  inline QTMGuiHelper (qt_gui_rep *_gui) : QObject (), gui (_gui) {}

protected:
  bool eventFilter (QObject *obj, QEvent *event);
  
public slots:
  void doUpdate ();
  void doRefresh ();
  void doReadSocketNotification (int socket);  
  void doWriteSocketNotification (int socket);  
  
signals:
  void refresh ();  
};


// this custom action frees its menu if it does not already have an owner.
class QTMAction : public QAction {
  
  Q_OBJECT
  
public:
  string str;
  
  QTMAction(QObject *parent = NULL);
  ~QTMAction();
  
  public slots:
  void doRefresh();
  
};


class QTMTranslator : public QTranslator {
  
  Q_OBJECT
  
public:
  QTMTranslator(QObject * parent = NULL ) : QTranslator(parent) {};
  virtual QString translate ( const char * context, const char * sourceText, 
                             const char * disambiguation = 0 ) const ;  
};

#endif // QTMGUIHELPER_HPP

==> texmacs_1.0.7.10.orig.tar.gz: TeXmacs-1.0.7.10-src/src/Plugins/Qt/QTMGuiHelper.hpp <==

/******************************************************************************
* MODULE     : QTMGuiHelper.hpp
* DESCRIPTION: QT Gui helper class. Infrastructure for delayed menu installation 
* COPYRIGHT  : (C) 2008 Massimiliano Gubinelli
*******************************************************************************
* This software falls under the GNU general public license version 3 or later.
* It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
* in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
******************************************************************************/

#ifndef QTMGUIHELPER_HPP
#define QTMGUIHELPER_HPP

#include "qt_gui.hpp"
#include "Scheme/object.hpp"
#include <QObject>
#include <QTranslator>

class QTMGuiHelper : public QObject {
  Q_OBJECT
  qt_gui_rep* gui;

public:
  inline QTMGuiHelper (qt_gui_rep *_gui) : QObject (), gui (_gui) {}

protected:
  bool eventFilter (QObject *obj, QEvent *event);
  
public slots:
  void doUpdate ();
  void doRefresh ();
  void doReadSocketNotification (int socket);  
  void doWriteSocketNotification (int socket);  
  
  void aboutToShowMainMenu ();
  void aboutToHideMainMenu ();
  void doPopWaitingWidgets ();
 
signals:
  void refresh ();  
};


class QTMTranslator : public QTranslator {
  
  Q_OBJECT
  
public:
  QTMTranslator(QObject * parent = NULL ) : QTranslator(parent) {};
  virtual QString translate ( const char * context, const char * sourceText, 
                             const char * disambiguation = 0 ) const ;  
};

#endif // QTMGUIHELPER_HPP
